@@ -21,11 +21,11 @@ has clone_uri_wiki_ssh_hggit   => ( is => 'lazy', isa => Str, init_arg => undef
 has cpan_meta => ( is => 'lazy', isa => HashRef, init_arg => undef );
 
 sub BUILDARGS ( $self, $args = undef ) {
-    $args->{api_username} ||= $ENV->user_cfg->{'Pcore::API::GitHub'}->{api_username} if $ENV->user_cfg->{'Pcore::API::GitHub'}->{api_username};
+    $args->{api_username} ||= $ENV->user_cfg->{GITHUB}->{username} if $ENV->user_cfg->{GITHUB}->{username};
 
-    $args->{api_token} ||= $ENV->user_cfg->{'Pcore::API::GitHub'}->{api_token} if $ENV->user_cfg->{'Pcore::API::GitHub'}->{api_token};
+    $args->{api_token} ||= $ENV->user_cfg->{GITHUB}->{token} if $ENV->user_cfg->{GITHUB}->{token};
 
-    $args->{namespace} ||= $ENV->user_cfg->{'Pcore::API::GitHub'}->{namespace} if $ENV->user_cfg->{'Pcore::API::GitHub'}->{namespace};
+    $args->{namespace} ||= $ENV->user_cfg->{GITHUB}->{namespace} if $ENV->user_cfg->{GITHUB}->{namespace};
 
     return $args;
 }
